@@ -28,16 +28,15 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include <libtracker-client/tracker.h>
-#include <libtracker-common/tracker-type-utils.h>
+#include <libtracker-common/tracker-common.h>
 #include <libtracker-miner/tracker-miner.h>
 
 #include "tracker-status-client.h"
 
-#define ABOUT	  \
+#define ABOUT \
 	"Tracker " PACKAGE_VERSION "\n"
 
-#define LICENSE	  \
+#define LICENSE \
 	"This program is free software and comes without any warranty.\n" \
 	"It is licensed under version 2 or later of the General Public " \
 	"License which can be viewed at:\n" \
@@ -135,6 +134,7 @@ signal_handler (int signo)
 		in_loop = TRUE;
 		g_main_loop_quit (main_loop);
 
+		/* Fall through */
 	default:
 		if (g_strsignal (signo)) {
 			g_print ("\n");
@@ -464,7 +464,6 @@ main (gint argc, gchar *argv[])
 {
 	TrackerMinerManager *manager;
 	GOptionContext *context;
-	TrackerClient *client;
 	GSList *miners_available;
 	GSList *miners_running;
 	GSList *l;
@@ -536,15 +535,6 @@ main (gint argc, gchar *argv[])
 		g_thread_init (NULL);
 	}
 
-	client = tracker_client_new (0, G_MAXINT);
-
-	if (!client) {
-		g_printerr ("%s\n",
-		            _("Could not establish a D-Bus connection to Tracker"));
-
-		return EXIT_FAILURE;
-	}
-
 	manager = tracker_miner_manager_new ();
 	miners_available = tracker_miner_manager_get_available (manager);
 	miners_running = tracker_miner_manager_get_running (manager);
@@ -601,7 +591,10 @@ main (gint argc, gchar *argv[])
 		g_slist_foreach (miners_running, (GFunc) g_free, NULL);
 		g_slist_free (miners_running);
 
-		g_object_unref (client);
+		if (proxy) {
+			g_object_unref (proxy);
+		}
+
 		return EXIT_SUCCESS;
 	}
 
@@ -746,7 +739,9 @@ main (gint argc, gchar *argv[])
 
 	if (!follow) {
 		/* Do nothing further */
-		g_object_unref (client);
+		if (proxy) {
+			g_object_unref (proxy);
+		}
 		g_print ("\n");
 		return EXIT_SUCCESS;
 	}
@@ -781,8 +776,13 @@ main (gint argc, gchar *argv[])
 	g_hash_table_unref (miners_progress);
 	g_hash_table_unref (miners_status);
 
-	g_object_unref (client);
-	g_object_unref (manager);
+	if (proxy) {
+		g_object_unref (proxy);
+	}
+
+	if (manager) {
+		g_object_unref (manager);
+	}
 
 	return EXIT_SUCCESS;
 }
